@@ -138,9 +138,9 @@ def delete_function(function_name, confirm=True):
         client = global_client["functions"]
         try:
             client.functions.delete(external_id=function_name)
-            logging.info(f"Deleted function with external-id {function_name=}")
+            logging.info(f"Deleted function with external id {function_name}")
         except CogniteNotFoundError:
-            logging.error(f"Couldn't find function with '{function_name=}'")
+            logging.error(f"Couldn't find function with external id {function_name}")
 
 
 def create_function_from_folder(
@@ -176,7 +176,7 @@ def create_function_from_folder(
         )
     except CogniteNotFoundError:
         logging.info(
-            f"Function {human_readable_name} with external id {function_name} does not exist"
+            f"Function {human_readable_name} with external id {function_name} does not exist and will be created"
         )
         pass
     
